@@ -1,9 +1,10 @@
 import numpy as np
+from typing import Union, Tuple, List
 
 
 
 class Problem:
-    def __init__(self, manifold, obj_fun, obj_grad=None, obj_hvp=None, beta = 0, enable_autodiff = True, backbone = None, enable_jit = True,  **kwargs):
+    def __init__(self, manifold, obj_fun, obj_grad=None, obj_hvp=None, beta:int = 0, enable_autodiff: bool = True, backbone = None, enable_jit:bool = True,  **kwargs):
         
         self.manifold = manifold
         self.obj_fun = obj_fun 
