@@ -10,14 +10,14 @@ from jax import random
 from .basic_manifold_jax import basic_manifold_jax
 
 class oblique_jax(basic_manifold_jax):
-    def __init__(self, var_shape) -> None:
+    def __init__(self, var_shape,train_mode = False) -> None:
         self.dim = var_shape[:-1]
         self._p = var_shape[-1]
 
 
         
-
-        super().__init__('oblique',var_shape, (*self.dim,1 ))
+        if not train_mode:
+            super().__init__('oblique',var_shape, (*self.dim,1 ))
 
     
 
